@@ -1,6 +1,8 @@
 from .geometry import array2pcd, pcd2array, merge_pcds
 
-__all__ == [
+__version__ = '0.0.1'
+
+__all__ = [
     'array2pcd',
     'pcd2array',
     'merge_pcds'
